# FAICE

FAICE (Fair Collaboration and Experiments) is part of the Curious Containers project and enables researchers to perform
and distribute reproducible data-driven experiments.

For more information please refer to the Curious Containers [project website](https://www.curious-containers.cc/) and 
[documentation](https://www.curious-containers.cc/docs/html/index.html).

## Acknowledgements

The Curious Containers software is developed at [CBMI](https://cbmi.htw-berlin.de/) (HTW Berlin -
University of Applied Sciences). The work is supported by the German Ministry of Economic Affairs and Energy (ZIM
Project BeCRF, Grant number KF3470401BZ4).
